Accessing the wisdom API from Fortran (FFTW 3.3.10)

Next: Defining an FFTW module, Previous: Allocating aligned memory in Fortran, Up: Calling FFTW from Modern Fortran [Contents][Index]

### 7.6 Accessing the wisdom API from Fortran

As explained in Words of Wisdom-Saving Plans, FFTW provides a “wisdom” API for saving plans to disk so that they can be recreated quickly. The C API for exporting (see Wisdom Export) and importing (see Wisdom Import) wisdom is somewhat tricky to use from Fortran, however, because of differences in file I/O and string types between C and Fortran.